==> vinli-android-sdk-4.1.19-sources.jar: li/vin/my/apikit/AuthSettings.kt <==
package li.vin.my.apikit

import android.content.Context
import android.content.SharedPreferences
import com.google.gson.Gson
import li.vin.my.apikit.models.LatestVehicle
import li.vin.my.apikit.models.Session

/**
 * 11/5/18.
 */
class AuthSettings private constructor(appContext: Context, appName: String) {
    private val sharedPreferences: SharedPreferences
    private val editor: SharedPreferences.Editor
    var authToken = ""

    init {
        sharedPreferences = appContext.getSharedPreferences("li.vin.net.Vinli." + appName, Context.MODE_PRIVATE)
        editor = sharedPreferences.edit()
    }

    fun addListener(listener: SharedPreferences.OnSharedPreferenceChangeListener) {
        sharedPreferences.registerOnSharedPreferenceChangeListener(listener)
    }

    companion object {
        private var settings: AuthSettings? = null

        val instance: AuthSettings
            get() {
                if (settings == null) {
                    throw IllegalArgumentException("No Context set in AuthSettings")
                }
                return settings!!
            }

        fun getInstance(context: Context?, appName: String): AuthSettings {
            if (context == null) {
                throw IllegalArgumentException("No Context set in AuthSettings")
            }
            if (settings == null) {
                settings = AuthSettings(context, appName)
            }

            return settings!!
        }

        private val DEVICE_ID = "DEVICE_ID"
        private val VEHICLE_ID = "VEHICLE_ID"
        private val COOKIE = "COOKIE"
        private val VEHICLE = "VEHICLE"
        private val SESSION = "SESSION"
        private val DRIVER_ID = "DRIVER_ID"
        private val EMAIL = "EMAIL"
        private val PASSWORD = "PASSWORD"
        private val CLIENT_ID = "CLIENT_ID"
    }

    fun getVehicleId(): String {
        sharedPreferences.getString(VEHICLE_ID, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getDeviceId(): String {
        sharedPreferences.getString(DEVICE_ID, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getDriverId(): String {
        sharedPreferences.getString(DRIVER_ID, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getEmail(): String {
        sharedPreferences.getString(EMAIL, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getPassword(): String {
        sharedPreferences.getString(PASSWORD, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getClientID(): String {
        sharedPreferences.getString(CLIENT_ID, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getSessionId(): String {
        sharedPreferences.getString(COOKIE, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getCurrentVehicleString(): String {
        sharedPreferences.getString(VEHICLE, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getCurrentSessionString(): String {
        sharedPreferences.getString(SESSION, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun setBearerToken(value: String) {
        authToken = "Bearer " + value
    }

    fun setEmail(value: String) {
        setEditPreferenceString(EMAIL, value)
    }

    fun setPassword(value: String) {
        setEditPreferenceString(PASSWORD, value)
    }

    fun setClientID(value: String) {
        setEditPreferenceString(CLIENT_ID, value)
    }

    fun setDriverId(value: String) {
        setEditPreferenceString(DRIVER_ID, value)
    }

    fun setDeviceId(value: String) {
        setEditPreferenceString(DEVICE_ID, value)
    }

    fun setVehicleId(value: String) {
        setEditPreferenceString(VEHICLE_ID, value)
    }

    fun setSessionId(value: String) {
        val sessionIdx = value.indexOf("session=")
        if (sessionIdx != -1) {
            var end = value.indexOf(";", sessionIdx)
            if (end == -1) end = value.length
            val cookie = "session=" + value.substring(sessionIdx + "session=".length, end).trim({ it <= ' ' })
            setEditPreferenceString(COOKIE, cookie)
        }
    }

    fun setCurrentVehicle(value: LatestVehicle?) {
        if (value != null) {
            val vehicleString = Gson().toJson(value)
            setEditPreferenceString(VEHICLE, vehicleString)
        } else {
            setEditPreferenceString(VEHICLE, "")
        }
    }

    fun setCurrentSession(value: Session?) {
        if (value != null) {
            val session = Gson().toJson(value)
            setEditPreferenceString(SESSION, session)
        } else {
            setEditPreferenceString(SESSION, "")
        }
    }

    /**
     * ------------ Setter Utilities ----------
     */

    fun keySession(key: String): Boolean {
        return SESSION == key
    }

    fun keyVehicle(key: String): Boolean {
        return VEHICLE_ID == key
    }

    fun keyDevice(key: String): Boolean {
        return DEVICE_ID == key
    }

    fun keyCookie(key: String): Boolean {
        return COOKIE == key
    }

    private fun setEditPreferenceStringSet(fileKey: String, fileValue: Set<String>) {
        editor.putStringSet(fileKey, fileValue)
        editor.commit()
    }

    private fun setEditPreferenceString(fileKey: String, fileValue: String) {
        editor.putString(fileKey, fileValue)
        editor.commit()
    }

    private fun setEditPreferenceBoolean(fileKey: String, fileValue: Boolean) {
        editor.putBoolean(fileKey, fileValue)
        editor.commit()
    }

    private fun setEditPreferenceInt(fileKey: String, fileValue: Int) {
        editor.putInt(fileKey, fileValue)
        editor.commit()
    }

    private fun setEditPreferenceLong(fileKey: String, fileValue: Long) {
        editor.putLong(fileKey, fileValue)
        editor.commit()
    }
}

fun String.getCurrentSession(): Session {
    return Gson().fromJson(this, Session::class.java)
}

fun String.getLatestVehicle(): LatestVehicle {
    return Gson().fromJson(this, LatestVehicle::class.java)
}

==> vinli-android-sdk-4.1.21-sources.jar: li/vin/my/apikit/AuthSettings.kt <==
package li.vin.my.apikit

import android.content.Context
import android.content.SharedPreferences
import androidx.security.crypto.EncryptedSharedPreferences
import androidx.security.crypto.MasterKeys
import com.google.gson.Gson
import li.vin.my.apikit.models.LatestVehicle
import li.vin.my.apikit.models.Session

/**
 * 11/5/18.
 */
class AuthSettings private constructor(appContext: Context, appName: String) {
    private val sharedPreferences: SharedPreferences
    private val editor: SharedPreferences.Editor
    var authToken = ""

    init {
        val masterKeyAlias: String = MasterKeys.getOrCreate(MasterKeys.AES256_GCM_SPEC)

        sharedPreferences = EncryptedSharedPreferences.create(
            "li.vin.net.Vinli." + appName,
            masterKeyAlias,
            appContext,
            EncryptedSharedPreferences.PrefKeyEncryptionScheme.AES256_SIV,
            EncryptedSharedPreferences.PrefValueEncryptionScheme.AES256_GCM
        )
        editor = sharedPreferences.edit()
    }

    fun addListener(listener: SharedPreferences.OnSharedPreferenceChangeListener) {
        sharedPreferences.registerOnSharedPreferenceChangeListener(listener)
    }

    companion object {
        private var settings: AuthSettings? = null

        val instance: AuthSettings
            get() {
                if (settings == null) {
                    throw IllegalArgumentException("No Context set in AuthSettings")
                }
                return settings!!
            }

        fun getInstance(context: Context?, appName: String): AuthSettings {
            if (context == null) {
                throw IllegalArgumentException("No Context set in AuthSettings")
            }
            if (settings == null) {
                settings = AuthSettings(context, appName)
            }

            return settings!!
        }

        private val DEVICE_ID = "DEVICE_ID"
        private val VEHICLE_ID = "VEHICLE_ID"
        private val COOKIE = "COOKIE"
        private val VEHICLE = "VEHICLE"
        private val SESSION = "SESSION"
        private val DRIVER_ID = "DRIVER_ID"
        private val EMAIL = "EMAIL"
        private val PASSWORD = "PASSWORD"
        private val CLIENT_ID = "CLIENT_ID"
    }

    fun getVehicleId(): String {
        sharedPreferences.getString(VEHICLE_ID, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getDeviceId(): String {
        sharedPreferences.getString(DEVICE_ID, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getDriverId(): String {
        sharedPreferences.getString(DRIVER_ID, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getEmail(): String {
        sharedPreferences.getString(EMAIL, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getPassword(): String {
        sharedPreferences.getString(PASSWORD, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getClientID(): String {
        sharedPreferences.getString(CLIENT_ID, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getSessionId(): String {
        sharedPreferences.getString(COOKIE, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getCurrentVehicleString(): String {
        sharedPreferences.getString(VEHICLE, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun getCurrentSessionString(): String {
        sharedPreferences.getString(SESSION, "")?.let {
            return it
        } ?: run {
            return ""
        }
    }

    fun setBearerToken(value: String) {
        authToken = "Bearer " + value
    }

    fun setEmail(value: String) {
        setEditPreferenceString(EMAIL, value)
    }

    fun setPassword(value: String) {
        setEditPreferenceString(PASSWORD, value)
    }

    fun setClientID(value: String) {
        setEditPreferenceString(CLIENT_ID, value)
    }

    fun setDriverId(value: String) {
        setEditPreferenceString(DRIVER_ID, value)
    }

    fun setDeviceId(value: String) {
        setEditPreferenceString(DEVICE_ID, value)
    }

    fun setVehicleId(value: String) {
        setEditPreferenceString(VEHICLE_ID, value)
    }

    fun setSessionId(value: String) {
        val sessionIdx = value.indexOf("session=")
        if (sessionIdx != -1) {
            var end = value.indexOf(";", sessionIdx)
            if (end == -1) end = value.length
            val cookie = "session=" + value.substring(sessionIdx + "session=".length, end).trim({ it <= ' ' })
            setEditPreferenceString(COOKIE, cookie)
        }
    }

    fun setCurrentVehicle(value: LatestVehicle?) {
        if (value != null) {
            val vehicleString = Gson().toJson(value)
            setEditPreferenceString(VEHICLE, vehicleString)
        } else {
            setEditPreferenceString(VEHICLE, "")
        }
    }

    fun setCurrentSession(value: Session?) {
        if (value != null) {
            val session = Gson().toJson(value)
            setEditPreferenceString(SESSION, session)
        } else {
            setEditPreferenceString(SESSION, "")
        }
    }

    /**
     * ------------ Setter Utilities ----------
     */

    fun keySession(key: String): Boolean {
        return SESSION == key
    }

    fun keyVehicle(key: String): Boolean {
        return VEHICLE_ID == key
    }

    fun keyDevice(key: String): Boolean {
        return DEVICE_ID == key
    }

    fun keyCookie(key: String): Boolean {
        return COOKIE == key
    }

    private fun setEditPreferenceStringSet(fileKey: String, fileValue: Set<String>) {
        editor.putStringSet(fileKey, fileValue)
        editor.commit()
    }

    private fun setEditPreferenceString(fileKey: String, fileValue: String) {
        editor.putString(fileKey, fileValue)
        editor.commit()
    }

    private fun setEditPreferenceBoolean(fileKey: String, fileValue: Boolean) {
        editor.putBoolean(fileKey, fileValue)
        editor.commit()
    }

    private fun setEditPreferenceInt(fileKey: String, fileValue: Int) {
        editor.putInt(fileKey, fileValue)
        editor.commit()
    }

    private fun setEditPreferenceLong(fileKey: String, fileValue: Long) {
        editor.putLong(fileKey, fileValue)
        editor.commit()
    }
}

fun String.getCurrentSession(): Session {
    return Gson().fromJson(this, Session::class.java)
}

fun String.getLatestVehicle(): LatestVehicle {
    return Gson().fromJson(this, LatestVehicle::class.java)
}
